schema

package
v0.131.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: AGPL-3.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateIndices added in v0.81.0

func CreateIndices(ctx context.Context, api *elasticsearch.TypedClient, opts *IndicesOptions) error

CreateIndices creates indices and appropriate read/write aliases.

func FavoritesIndexRO added in v0.88.1

func FavoritesIndexRO() string

func FavoritesIndexRW added in v0.88.1

func FavoritesIndexRW() string

func FeedsIndexRO

func FeedsIndexRO() string

func FeedsIndexRW

func FeedsIndexRW() string

func ItemsIndexRO

func ItemsIndexRO() string

func ItemsIndexRW

func ItemsIndexRW() string

func MigrateIndices added in v0.87.0

func MigrateIndices(ctx context.Context, api *elasticsearch.TypedClient, opts *IndicesOptions) error

MigrateIndices performs all requested schema migrations.

func SchedulerIndexRO

func SchedulerIndexRO() string

func SchedulerIndexRW

func SchedulerIndexRW() string

func SessionsIndexRO

func SessionsIndexRO() string

func SessionsIndexRW

func SessionsIndexRW() string

func SubscriptionsIndexRO

func SubscriptionsIndexRO() string

func SubscriptionsIndexRW

func SubscriptionsIndexRW() string

func UpdateILMPolicies added in v0.87.0

func UpdateILMPolicies(ctx context.Context, api *elasticsearch.TypedClient, opts *ILMOptions) error

UpdateILMPolicies will update all the specified ILM policies.

func UpdateIndicesSchema added in v0.87.0

func UpdateIndicesSchema(ctx context.Context, api *elasticsearch.TypedClient, opts *IndicesOptions) error

UpdateIndicesSchema performs all requested schema migrations.

func UsersIndexRO

func UsersIndexRO() string

func UsersIndexRW

func UsersIndexRW() string

Types

type ILMOptions added in v0.87.0

type ILMOptions struct {
	Policies []string `arg:"" default:"all" enum:"all,logs"`
}

ILMOptions contains the options for performing ILM schema operations.

type IndicesOptions added in v0.87.0

type IndicesOptions struct {
	Indices []string `` /* 139-byte string literal not displayed */
}

IndicesOptions contains the options for performing index schema operations.

type Option

type Option[T any] func(T)

Option is a reusable generic function for applying options to a type.

Jump to