aggregations

package
v0.28.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package aggregations contains objects and methods for processing Elasticsearch aggregations.

Index

Constants

This section is empty.

Variables

var (
	// Aggregation Errors.
	ErrInvalidAggType = errors.New("not requested aggregation type")
)

Functions

func ExtractAggregation

func ExtractAggregation[T any](aggs map[string]types.Aggregate, name string) (T, error)

ExtractAggregation extracts the named aggregation as the requested type from the search response.

Types

type Aggs

type Aggs map[string]types.Aggregations

Jump to