ingest

package
v0.47.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewIngestPipeline

func NewIngestPipeline(options ...Option) *putpipeline.Request

NewIngestPipeline creates a new ingest pipeline from the given options.

Types

type Option

type Option func(*putpipeline.Request)

Option is a functional option for a reindex operation.

func WithProcessor

func WithProcessor(processer types.ProcessorContainer) Option

Jump to