github

package
v0.164.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2026 License: AGPL-3.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	// ConfigEnvPrefix is the prefix applied to environment variables for configuring Auth0.
	ConfigEnvPrefix = config.ConfigEnvPrefix + "GITHUB_"
)

Variables

This section is empty.

Functions

func Connect

func Connect(ctx context.Context) error

Connect will create a client connection with the GitHub API. The connection will be cached for re-use. It is safe to call multiple times, with subsequent calls being no-ops.

Types

type Config

type Config struct {
	Key            string `koanf:"privatekey"     validate:"required"`
	ClientID       string `koanf:"clientid"       validate:"required"`
	InstallationID int    `koanf:"installationid"`
	IssuesRepo     string `koanf:"issuesrepo"     validate:"required"`
}

Config structure.

Jump to