billing

package
v0.130.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: AGPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateBudget

func CreateBudget(ctx context.Context, budget *Budget) (string, error)

CreateBudget creates a new budget with the given information. It will return the newly created budget resource id or a non-nil error if creation failed.

Types

type Budget

type Budget struct {
	Name            string `json:"name"`
	DisplayName     string `json:"budgetDisplayName"`
	CurrencyCode    string `json:"currencyCode"`
	Units           int64  `json:"units"`
	ThresholdAlerts []float64
}

type BudgetAlert

type BudgetAlert struct {
	*Budget

	AlertThresholdExceeded float64 `json:"alertThresholdExceeded"`
	BudgetAmount           float64 `json:"budgetAmount"`
	CostAmount             float64 `json:"costAmount"`
}

Jump to