pubsub

package
v0.87.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateTopic added in v0.79.1

func CreateTopic(ctx context.Context, topic string) error

CreateTopic creates the topic with the given name.

func GetClient added in v0.79.1

func GetClient(ctx context.Context) (*pubsub.Client, error)

GetClient returns the pubsub client.

func TopicExists added in v0.79.1

func TopicExists(ctx context.Context, topic string) (bool, error)

TopicExists returns a boolean indicating whether the given pubsub topic exists. If there was a problem, it will return a non-nil error as the second return value.

Types

This section is empty.

Jump to