youtube

package
v0.159.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Channel

type Channel struct {
	ID          string
	Title       string
	Description string
	PublishedAt string
	Image       *models.RemoteImage
}

Channel represents a Youtube channel. It contains the id, title, description, published date and an image.

func FindChannels

func FindChannels(ctx context.Context, query string) ([]Channel, error)

FindChannels will search Youtube for channels matching the given query string and return a slice of matches.

Jump to