scheduler

package
v0.167.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2026 License: AGPL-3.0 Imports: 18 Imported by: 0

Documentation

Overview

Package scheduler contains code for the scheduler backend that handles managing background jobs for the application.

Index

Constants

This section is empty.

Variables

var Manager *manager

Functions

func LoadManager added in v0.87.0

func LoadManager(ctx context.Context) error

func NewManager added in v0.24.0

func NewManager(ctx context.Context) error

NewManager will create a new manager object containing the scheduler and job queue.

func Run

func Run(ctx context.Context) error

Run starts the scheduler manager.

func RunStartupTasks added in v0.24.0

func RunStartupTasks(ctx context.Context) error

RunStartupTasks will run a bunch of tasks that should be done when the scheduler first starts. Effectively, this seeds the job queue with some required jobs for scheduler functionality and maintenance.

Types

This section is empty.

Directories

Path Synopsis
Package jobs provides primitives to interact with the openapi HTTP API.
Package jobs provides primitives to interact with the openapi HTTP API.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.

Jump to