Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func ReadEncrypted ¶
ReadEncrypted will read an encrypted cookie from the request.
func Write ¶
func Write(res http.ResponseWriter, cookie http.Cookie) error
Write will write the given cookie to the response.
func WriteEncrypted ¶
WriteEncrypted will write an encrypted cookie to the response.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.