Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleImage ¶
func HandleImage() http.HandlerFunc
HandleImage is handler that will attempt to proxy an image through the image proxy. It will fetch, store and retrieve the image from the cache as needed.
Types ¶
Click to show internal directories.
Click to hide internal directories.