web

package
v0.175.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DocsFS embed.FS
var StaticContentFS embed.FS

Functions

func GetScriptFilenames

func GetScriptFilenames() []string

func GetStyleFilenames

func GetStyleFilenames() []string

Types

This section is empty.

Directories

Path Synopsis
helpers/mailto
Package mailto provides a method for easily constructing a mailto: string for use in links.
Package mailto provides a method for easily constructing a mailto: string for use in links.

Jump to