partials

package
v0.166.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2026 License: AGPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	ImgProxyKey  contextKey = "imgproxy_key"
	ImgProxySalt contextKey = "imgproxy_salt"
)
const ModalContainerID = models.ElementID("modals")

ModalContainerID points to an element that holds a modal.

Variables

This section is empty.

Functions

func Card added in v0.98.0

func Card(options ...element.PropertiesOption) templ.Component

func CardBody added in v0.98.0

func CardBody(options ...element.PropertiesOption) templ.Component

func CardFooter added in v0.98.0

func CardFooter(options ...element.PropertiesOption) templ.Component

func CardHeader added in v0.98.0

func CardHeader(options ...element.PropertiesOption) templ.Component

func FAQ added in v0.143.0

func FAQ(entries []FAQEntry) templ.Component

func FormDisclosure added in v0.82.3

func FormDisclosure(label string) templ.Component

func FormField added in v0.82.4

func FormField() templ.Component

func FormSection added in v0.82.4

func FormSection() templ.Component

func GenerateImageProxyURL added in v0.73.0

func GenerateImageProxyURL(ctx context.Context, url, props string) string

func HelpPopover added in v0.79.0

func HelpPopover(id, anchor string) templ.Component

HelpPopover can be used to render a help icon, that when clicked, will open a popover displaying informational or help text.

func LoadingIndicator added in v0.75.0

func LoadingIndicator(id string) templ.Component

LoadingIndicator adds a loading indicator that is displayed while a HTMX request is processing.

func Logo(options ...element.PropertiesOption) templ.Component
func Menu(options ...element.PropertiesOption) templ.Component
func MenuItem(options ...element.PropertiesOption) templ.Component
func Modal(id string, open bool) templ.Component

Modal will render a modal with the given content.

func NewProxiedImage added in v0.73.0

func NewProxiedImage(img *models.RemoteImage, props string, options ...element.PropertiesOption) templ.Component

func NoContent added in v0.84.0

func NoContent() templ.Component

func ObfuscateEmail added in v0.98.0

func ObfuscateEmail(email, label string) templ.Component

func ReadingProgress added in v0.123.0

func ReadingProgress() templ.Component

func RenderJSONLD added in v0.143.0

func RenderJSONLD(id string, data json.RawMessage) templ.Component

func SubscriptionSuggestions added in v0.82.3

func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component

SubscriptionSuggestions renders the given subscriptions as options for an autocomplete dropdown.

func Thumbnail added in v0.73.0

func Thumbnail(img *models.RemoteImage, name string, size string) templ.Component

Types

type FAQEntry added in v0.143.0

type FAQEntry struct {
	ID       string
	Question string
	Answer   string
}

FAQEntry represents a single question and answer pair.

type ProxiedImage added in v0.73.0

type ProxiedImage struct {
	*element.Properties
}

Jump to