slots

package
v0.159.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 12, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	Header = "header"
)

Variables

This section is empty.

Functions

func GetSlot

func GetSlot(ctx context.Context, key string) templ.Component

GetSlot retrieves a component from context by key. Returns nil if the Slot was not set.

func HasSlot

func HasSlot(ctx context.Context, key string) bool

HasSlot reports whether a Slot was set in context.

func WithSlot

func WithSlot(ctx context.Context, key string, c templ.Component) context.Context

WithSlot stores a component in context under a named key.

Types

This section is empty.

Jump to