Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindAllHTMLNodes ¶
FindAllHTMLNodes returns all nodes matching the tag within n.
func FindHTMLNode ¶
FindHTMLNode does a depth-first search for the first node matching the tag.
func FindMainImage ¶
FindMainImage tries to find a "main" image for the page, using the readability parser.
func IsHTMLElement ¶
IsHTMLElement returns a boolean indicating whether the given string is the given HTML element.
Types ¶
Click to show internal directories.
Click to hide internal directories.