Documentation
¶
Index ¶
Constants ¶
const ( // ConfigEnvPrefix is the prefix applied to environment variables for configuring Auth0. ConfigEnvPrefix = config.ConfigEnvPrefix + "GITHUB_" )
Variables ¶
This section is empty.
Functions ¶
func Connect ¶
Connect will create a client connection with the GitHub API. The connection will be cached for re-use. It is safe to call multiple times, with subsequent calls being no-ops.
func CreateIssue ¶
func CreateIssue(ctx context.Context, details *models.ReportIssueRequest) error
CreateIssue creates a new issue in Github about problems with the app reported by a user.
func CreateObjectIssue ¶
func CreateObjectIssue(ctx context.Context, details *models.ReportObjectIssueRequest) error
CreateObjectIssue creates a new issue in Github about problems with a particular object reported by a user.
Types ¶
Click to show internal directories.
Click to hide internal directories.