github

package
v0.78.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: AGPL-3.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

const (
	// ConfigEnvPrefix is the prefix applied to environment variables for configuring Auth0.
	ConfigEnvPrefix = config.ConfigEnvPrefix + "GITHUB_"
)

Variables

This section is empty.

Functions

func Connect

func Connect(ctx context.Context) error

Connect will create a client connection with the GitHub API. The connection will be cached for re-use. It is safe to call multiple times, with subsequent calls being no-ops.

func CreateIssue

func CreateIssue(ctx context.Context, details *models.ReportIssueRequest) error

CreateIssue creates a new issue in Github about problems with the app reported by a user.

func CreateObjectIssue

func CreateObjectIssue(ctx context.Context, details *models.ReportObjectIssueRequest) error

CreateObjectIssue creates a new issue in Github about problems with a particular object reported by a user.

Types

type Config

type Config struct {
	Key            string `koanf:"privatekey"     validate:"required"`
	ClientID       string `koanf:"clientid"       validate:"required"`
	InstallationID int    `koanf:"installationid"`
	IssuesRepo     string `koanf:"issuesrepo"     validate:"required"`
}

Config structure.

Jump to