Discover Packages
github.com/immanent-tech/foragd
providers
google
billing
package
Version:
v0.130.1
Opens a new window with list of versions in this module.
Published: May 8, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
CreateBudget creates a new budget with the given information. It will return the newly created budget resource id or
a non-nil error if creation failed.
type Budget struct {
Name string `json:"name"`
DisplayName string `json:"budgetDisplayName"`
CurrencyCode string `json:"currencyCode"`
Units int64 `json:"units"`
ThresholdAlerts []float64
}
type BudgetAlert struct {
*Budget
AlertThresholdExceeded float64 `json:"alertThresholdExceeded"`
BudgetAmount float64 `json:"budgetAmount"`
CostAmount float64 `json:"costAmount"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.