scheduler

package
v0.82.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: AGPL-3.0 Imports: 16 Imported by: 0

Documentation

Overview

Package scheduler contains code for the scheduler backend that handles managing background jobs for the application.

Index

Constants

This section is empty.

Variables

var Manager *manager

Functions

func NewManager added in v0.24.0

func NewManager(ctx context.Context) error

NewManager will create a new manager object containing the scheduler and job queue.

func Run

func Run(ctx context.Context) error

Run starts the scheduler manager.

func RunStartupTasks added in v0.24.0

func RunStartupTasks(ctx context.Context) error

RunStartupTasks will run a bunch of tasks that should be done when the scheduler first starts. Effectively, this seeds the job queue with some required jobs for scheduler functionality and maintenance.

Types

This section is empty.

Directories

Path Synopsis
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs.
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.

Jump to