Documentation
¶
Overview ¶
Package scheduler contains code for the scheduler backend that handles managing background jobs for the application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Manager *manager
Functions ¶
func NewManager ¶ added in v0.24.0
NewManager will create a new manager object containing the scheduler and job queue.
func RunStartupTasks ¶ added in v0.24.0
RunStartupTasks will run a bunch of tasks that should be done when the scheduler first starts. Effectively, this seeds the job queue with some required jobs for scheduler functionality and maintenance.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs.
|
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs. |
|
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.
|
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend. |
Click to show internal directories.
Click to hide internal directories.