scheduler

package
v0.19.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2026 License: AGPL-3.0 Imports: 15 Imported by: 0

Documentation

Overview

Package scheduler contains code for the scheduler backend that handles managing background jobs for the application.

Index

Constants

This section is empty.

Variables

var ErrScheduler = errors.New("scheduler encountered an error")
var Manager *manager

Functions

func Run

func Run(ctx context.Context) error

Run starts the scheduler manager.

Types

This section is empty.

Directories

Path Synopsis
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs.
Package jobs implements a common type for quartz jobs and specific types and methods to execute different kinds of jobs.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.
Package queue implements a quartz.JobQueue using Elasticsearch as the storage backend.

Jump to