imgproxy

package
v0.167.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2026 License: AGPL-3.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetKey

func GetKey() (string, error)

func GetSalt

func GetSalt() (string, error)

func HandleImage

func HandleImage() http.HandlerFunc

HandleImage is handler that will attempt to proxy an image through the image proxy. It will fetch, store and retrieve the image from the cache as needed.

Types

type Config

type Config struct {
	Key    string `koanf:"key"    validate:"required,base64rawurl"`
	Salt   string `koanf:"salt"   validate:"required,base64rawurl"`
	Prefix string `koanf:"prefix" validate:"required,url"`
}

Jump to