Documentation
¶
Overview ¶
Package session contains methods and objects for managing user sessions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Clear ¶
Clear deletes the session data from the session store and sets the session status to Destroyed. Any further operations in the same request cycle will result in a new session being created.
func LoadAndSave ¶
LoadAndSave middleware handles loading the session data for a request and saving any modifications.
func NewSessionManager ¶
func NewSessionManager() error
NewSessionManager creates a new session manager.
func Renew ¶ added in v0.51.0
Renew updates the session data to have a new session token while retaining the current session data. The session lifetime is also reset and the session data status will be set to Modified. The old session token and accompanying data are deleted from the session store.
Types ¶
This section is empty.