validation

package
v0.80.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrInvalid = errors.New("object is invalid")
var ErrNilObject = errors.New("object is nil")

Functions

func IsValid

func IsValid[T any](obj T) bool

IsValid will check if an object is valid according to the validation tags on the object. It does not return any details of validation issues, only a boolean for valid (true) or invalid (false).

func SanitizeString

func SanitizeString(str string) string

SanitizeString attempts to "sanitize" a string value. It will strip any leading/trailing whitespace and then run the string through bluemonday to remove dangerous components. This should retain HTML5 content.

Types

type Error

type Error struct {
	Details string
	// contains filtered or unexported fields
}

Error is a map of fields and their validation errors.

func (*Error) Error

func (e *Error) Error() string

Jump to