Documentation
¶
Index ¶
- Constants
- func Card(options ...element.PropertiesOption) templ.Component
- func CardBody(options ...element.PropertiesOption) templ.Component
- func CardFooter(options ...element.PropertiesOption) templ.Component
- func CardHeader(options ...element.PropertiesOption) templ.Component
- func FAQ(entries []FAQEntry) templ.Component
- func FormDisclosure(label string) templ.Component
- func FormField() templ.Component
- func FormSection() templ.Component
- func GenerateImageProxyURL(ctx context.Context, url, props string) string
- func HelpPopover(id, anchor string) templ.Component
- func LoadingIndicator(id string) templ.Component
- func Logo(options ...element.PropertiesOption) templ.Component
- func Menu(options ...element.PropertiesOption) templ.Component
- func MenuItem(options ...element.PropertiesOption) templ.Component
- func Modal(id string, open bool) templ.Component
- func NewProxiedImage(img *models.RemoteImage, props string, options ...element.PropertiesOption) templ.Component
- func NoContent() templ.Component
- func ObfuscateEmail(email, label string) templ.Component
- func ReadingProgress() templ.Component
- func RenderJSONLD(id string, data json.RawMessage) templ.Component
- func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component
- func Thumbnail(img *models.RemoteImage, name string, size string) templ.Component
- type FAQEntry
- type ProxiedImage
Constants ¶
const ( ImgProxyKey contextKey = "imgproxy_key" ImgProxySalt contextKey = "imgproxy_salt" )
const ModalContainerID = models.ElementID("modals")
ModalContainerID points to an element that holds a modal.
Variables ¶
This section is empty.
Functions ¶
func CardFooter ¶ added in v0.98.0
func CardFooter(options ...element.PropertiesOption) templ.Component
func CardHeader ¶ added in v0.98.0
func CardHeader(options ...element.PropertiesOption) templ.Component
func FormDisclosure ¶ added in v0.82.3
func FormSection ¶ added in v0.82.4
func GenerateImageProxyURL ¶ added in v0.73.0
func HelpPopover ¶ added in v0.79.0
HelpPopover can be used to render a help icon, that when clicked, will open a popover displaying informational or help text.
func LoadingIndicator ¶ added in v0.75.0
LoadingIndicator adds a loading indicator that is displayed while a HTMX request is processing.
func MenuItem ¶ added in v0.150.1
func MenuItem(options ...element.PropertiesOption) templ.Component
func NewProxiedImage ¶ added in v0.73.0
func NewProxiedImage(img *models.RemoteImage, props string, options ...element.PropertiesOption) templ.Component
func ObfuscateEmail ¶ added in v0.98.0
func ReadingProgress ¶ added in v0.123.0
func RenderJSONLD ¶ added in v0.143.0
func RenderJSONLD(id string, data json.RawMessage) templ.Component
func SubscriptionSuggestions ¶ added in v0.82.3
func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component
SubscriptionSuggestions renders the given subscriptions as options for an autocomplete dropdown.
Types ¶
type ProxiedImage ¶ added in v0.73.0
type ProxiedImage struct {
*element.Properties
}
Click to show internal directories.
Click to hide internal directories.