partials

package
v0.83.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: AGPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	ImgProxyKey  contextKey = "imgproxy_key"
	ImgProxySalt contextKey = "imgproxy_salt"
)
const ModalContainerID = models.ElementID("modals")

ModalContainerID points to an element that holds a modal.

Variables

This section is empty.

Functions

func ButtonBack added in v0.35.0

func ButtonBack() templ.Component

ButtonBack adds a button that will trigger the browser to navigate back in history.

func ButtonBackToTop added in v0.35.0

func ButtonBackToTop() templ.Component

ButtonBackToTop adds a "back to top" button that is only shown when the user has scrolled down the page.

func FormDisclosure added in v0.82.3

func FormDisclosure(label string) templ.Component

func FormField added in v0.82.4

func FormField() templ.Component

func FormSection added in v0.82.4

func FormSection() templ.Component

func GenerateImageProxyURL added in v0.73.0

func GenerateImageProxyURL(ctx context.Context, url, props string) string

func HelpPopover added in v0.79.0

func HelpPopover(id, anchor string) templ.Component

HelpPopover can be used to render a help icon, that when clicked, will open a popover displaying informational or help text.

func LoadingIndicator added in v0.75.0

func LoadingIndicator(id string) templ.Component

LoadingIndicator adds a loading indicator that is displayed while a HTMX request is processing.

func Modal(id string, open bool) templ.Component

Modal will render a modal with the given content.

func NewProxiedImage added in v0.73.0

func NewProxiedImage(img *models.RemoteImage, props string, options ...element.Option) templ.Component

func SubscriptionSuggestions added in v0.82.3

func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component

SubscriptionSuggestions renders the given subscriptions as options for an autocomplete dropdown.

func Thumbnail added in v0.73.0

func Thumbnail(img *models.RemoteImage, name string, size string) templ.Component

Types

type ProxiedImage added in v0.73.0

type ProxiedImage struct {
	*element.Element
}

Jump to