Documentation
¶
Index ¶
- Constants
- func ButtonBack() templ.Component
- func ButtonBackToTop() templ.Component
- func FormDisclosure(label string) templ.Component
- func FormField() templ.Component
- func FormSection() templ.Component
- func GenerateImageProxyURL(ctx context.Context, url, props string) string
- func HelpPopover(id, anchor string) templ.Component
- func LoadingIndicator(id string) templ.Component
- func Modal(id string, open bool) templ.Component
- func NewProxiedImage(img *models.RemoteImage, props string, options ...element.Option) templ.Component
- func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component
- func Thumbnail(img *models.RemoteImage, name string, size string) templ.Component
- type ProxiedImage
Constants ¶
const ( ImgProxyKey contextKey = "imgproxy_key" ImgProxySalt contextKey = "imgproxy_salt" )
const ModalContainerID = models.ElementID("modals")
ModalContainerID points to an element that holds a modal.
Variables ¶
This section is empty.
Functions ¶
func ButtonBack ¶ added in v0.35.0
ButtonBack adds a button that will trigger the browser to navigate back in history.
func ButtonBackToTop ¶ added in v0.35.0
ButtonBackToTop adds a "back to top" button that is only shown when the user has scrolled down the page.
func FormDisclosure ¶ added in v0.82.3
func FormSection ¶ added in v0.82.4
func GenerateImageProxyURL ¶ added in v0.73.0
func HelpPopover ¶ added in v0.79.0
HelpPopover can be used to render a help icon, that when clicked, will open a popover displaying informational or help text.
func LoadingIndicator ¶ added in v0.75.0
LoadingIndicator adds a loading indicator that is displayed while a HTMX request is processing.
func NewProxiedImage ¶ added in v0.73.0
func SubscriptionSuggestions ¶ added in v0.82.3
func SubscriptionSuggestions(subscriptions models.Subscriptions) templ.Component
SubscriptionSuggestions renders the given subscriptions as options for an autocomplete dropdown.
Types ¶
type ProxiedImage ¶ added in v0.73.0
Click to show internal directories.
Click to hide internal directories.