partials

package
v0.57.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const ModalContainerID = models.ElementID("modals")

ModalContainerID points to an element that holds a modal.

Variables

This section is empty.

Functions

func ButtonBack added in v0.35.0

func ButtonBack() templ.Component

ButtonBack adds a button that will trigger the browser to navigate back in history.

func ButtonBackToTop added in v0.35.0

func ButtonBackToTop() templ.Component

ButtonBackToTop adds a "back to top" button that is only shown when the user has scrolled down the page.

func Heading1 added in v0.40.0

func Heading1(text string) templ.Component

func Heading2 added in v0.40.0

func Heading2() templ.Component

func Heading3 added in v0.40.0

func Heading3() templ.Component
func Modal(id string, open bool) templ.Component

Modal will render a modal with the given content.

func Paragraph added in v0.40.0

func Paragraph() templ.Component

Types

This section is empty.

Jump to