Documentation
¶
Index ¶
Constants ¶
const ModalContainerID = models.ElementID("modals")
ModalContainerID points to an element that holds a modal.
Variables ¶
This section is empty.
Functions ¶
func ButtonBack ¶ added in v0.35.0
ButtonBack adds a button that will trigger the browser to navigate back in history.
func ButtonBackToTop ¶ added in v0.35.0
ButtonBackToTop adds a "back to top" button that is only shown when the user has scrolled down the page.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.